@@ -10,7 +10,7 @@ use Carp;
 
 
 
-our $VERSION = "0.014.1";
+our $VERSION = "0.018.1";
 
 use Text::Layout::FontDescriptor;
 
@@ -23,11 +23,11 @@ Text::Layout::FontConfig - Pango style font description for Text::Layout
 Font descriptors are strings that identify the characteristics of the
 desired font. For example, C<Sans Italic 20>.
 
-The PDF context deals with fysical fonts, e.g. built-in fonts like
+The PDF context deals with physical fonts, e.g. built-in fonts like
 C<Times-Bold> and fonts loaded from font files like
 C</usr/share/fonts/dejavu/DejaVuSans.ttf>.
 
-To map font descriptions to fysical fonts, these fonts must be
+To map font descriptions to physical fonts, these fonts must be
 registered. This defines a font family, style, and weight for the
 font.
 
@@ -78,7 +78,7 @@ sub new {
 
 =over
 
-=item register_fonts( $font, $family, $style, $weight )
+=item register_fonts( $font, $family, $style [ , $weight ] [ , $props ] )
 
 Registers a font fmaily, style and weight for the given font.
 
@@ -95,12 +95,34 @@ $weight is the font weight, like C<normal>, or C<bold>.
 
 For convenience, style combinations like "bolditalic" are allowed.
 
+A final hash reference can be passed to specify additional properties
+for this font. Recognized properties are:
+
+=over
+
+=item *
+
+C<shaping> - If set to a true value, this font will require text
+shaping. This is required for fonts that deal with complex glyph
+rendering and ligature handling like Devanagari.
+
+Text shaping requires module L<HarfBuzz::Shaper>.
+
+=item *
+
+C<interline> - If set to a true value, an alternative way to determine
+glyph height is used. This may improve results for some fonts.
+
+=back
+
 =back
 
 =cut
 
 sub register_font {
     shift if UNIVERSAL::isa( $_[0], __PACKAGE__ );
+    my $props;
+    $props = pop(@_) if UNIVERSAL::isa( $_[-1], 'HASH' );
     my ( $font, $family, $style, $weight ) = @_;
 
     if ( $style && !$weight && $style =~ s/^bold//i ) {
@@ -132,6 +154,10 @@ sub register_font {
     foreach ( split(/\s*,\s*/, $family) ) {
 	$fonts{lc $_}->{$style}->{$weight}->{loader} = $loader;
 	$fonts{lc $_}->{$style}->{$weight}->{loader_data} = $ff;
+	next unless $props;
+	while ( my($k,$v) = each %$props ) {
+	    $fonts{lc $_}->{$style}->{$weight}->{$k} = $v;
+	}
     }
 
 }
@@ -265,7 +291,9 @@ On Linux, fallback using fontconfig.
 
 sub find_font {
     shift if UNIVERSAL::isa( $_[0], __PACKAGE__ );
-    my ( $family, $style, $weight, $atts ) = @_;
+    my $atts;
+    $atts = pop(@_) if UNIVERSAL::isa( $_[-1], 'HASH' );
+    my ( $family, $style, $weight ) = @_;
 
     my $try = sub {
       if ( $fonts{$family}
@@ -277,7 +305,10 @@ sub find_font {
 	      ( font   => $ff,
 		family => $family,
 		style  => $style,
-		weight => $weight );
+		weight => $weight,
+		shaping => $fonts{$family}->{$style}->{$weight}->{shaping},
+		interline => $fonts{$family}->{$style}->{$weight}->{interline},
+	      );
 	}
 	elsif ( $ff = $fonts{$family}->{$style}->{$weight}->{loader_data} ) {
 	    return Text::Layout::FontDescriptor->new
@@ -286,7 +317,10 @@ sub find_font {
 		cache  => $fonts{$family}->{$style}->{$weight},
 		family => $family,
 		style  => $style,
-		weight => $weight );
+		weight => $weight,
+		shaping => $fonts{$family}->{$style}->{$weight}->{shaping},
+		interline => $fonts{$family}->{$style}->{$weight}->{interline},
+	     );
 	}
 	else {
 	    return;
@@ -336,6 +370,8 @@ sub from_string {
     $res;
 }
 
+=over
+
 =item parse( $description )
 
 Parses a Pango-style font description and returns a hash ref with keys
@@ -376,6 +412,7 @@ sub parse {
 	}
 	else {
 	    carp("Unknown font property: $t");
+	    $family .= " " . $_;
 	}
     }
 
@@ -522,12 +559,12 @@ You can find documentation for this module with the perldoc command.
 
   perldoc Text::Layout::FontConfig
 
-Please report any bugs or feature requests using the issue tracker on
-GitHub.
+Please report any bugs or feature requests using the issue tracker for
+Text::Layout on GitHub.
 
 =head1 LICENSE
 
-See L<Text::Layout>.
+See L<Text::Layout>, L<Text::Layout::FontDescriptor>, L<HarfBuzz::Shaper>.
 
 =cut
 
@@ -537,10 +574,12 @@ sub _dump {
 	    foreach my $weight ( qw( normal bold ) ) {
 		my $f = $fonts{$family}{$style}{$weight};
 		next unless $f;
-		printf STDERR ( "%-13s %s%s%s %s\n",
+		printf STDERR ( "%-13s %s%s%s%s%s %s\n",
 				$family,
 				$style eq 'normal' ? "-" : "i",
 				$weight eq 'normal' ? "-" : "b",
+				$f->{shaping} ? "s" : "-",
+				$f->{interline} ? "l" : "-",
 				$f->{font} ? "+" : " ",
 				$f->{loader_data},
 			      );
